pub struct CompletionItem {
pub label: String,
pub kind: Option<CompletionItemKind>,
pub detail: Option<String>,
pub documentation: Option<CompletionItemDocumentation>,
pub preselect: Option<bool>,
pub sort_text: Option<String>,
pub filter_text: Option<String>,
}Expand description
Completion item
Fields
label: StringThe label of this completion item
kind: Option<CompletionItemKind>The kind of this completion item
detail: Option<String>A human-readable string with additional information
documentation: Option<CompletionItemDocumentation>A human-readable string that represents a doc-comment
preselect: Option<bool>Select this item when showing
sort_text: Option<String>A string that should be used when comparing this item with other items
filter_text: Option<String>A string that should be used when filtering items
Implementations